import javax.swing.*;
import java.awt.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

public class DrawingFrame extends JFrame {
	private ShapeContainer shapeContainer;
	private Panel buttonPanel;
	private Panel choicePanel;

	private int currentShape;
	private Color currentColor;

	private boolean fillState;

	public DrawingFrame(String title) {
		super(title);

		// initiate panel of shape buttons
		buttonPanel = new Panel();
		new ButtonController(this);
		getContentPane().add("South", buttonPanel);

		// initiate panel of color choices
		choicePanel = new Panel();
		new ChoiceController(this);
		getContentPane().add("East", choicePanel);

		// initiate label
		Label name = new Label("그림판");
		getContentPane().add("North", name);

		// initiate canvas
		shapeContainer = new ShapeContainer();
		new CanvasMouseController(this);
		getContentPane().add("Center", shapeContainer);

		// set initial state
		currentShape = Shape.LINE;
		currentColor = Color.BLACK;
		fillState = false;

		addWindowListener(new LocalWindowListener());

		setSize(500, 500);
		setVisible(true);
	}

	public Container getShapeContainer() { return shapeContainer; }

	public Panel getButtonPanel() { return buttonPanel; }

	public Panel getChoicePanel() { return choicePanel; }

	public void setCurrShape(int shape) { currentShape = shape; }

	public int getCurrShape() { return currentShape; }

	public void setShapeContainer(ShapeContainer s) { getContentPane().add(s); }

	public void setCurrentColor(Color c) { currentColor = c; }

	public Color getCurrentColor() { return currentColor; }

	public void setFillState(boolean b) { fillState = b; }

	public boolean getFillState() { return fillState; }

	
	public void addShape(Point p1, Point p2) {
		Shape newShape;

		switch (getCurrShape()) {
			case Shape.CIRCLE:
				newShape = new Circle(p1, p2);
				break;

			case Shape.RECT:
				newShape = new Rectangular(p1, p2);
				break;

			case Shape.LINE:
				newShape = new Line(p1, p2);
				break;

			default:
				return;
		}

		newShape.setColor(getCurrentColor());
		newShape.setFill(getFillState());
		shapeContainer.add(newShape);
		repaint();
	}


	public void removeFrontShape() {
		shapeContainer.remove(shapeContainer.getComponentCount() - 1);
		repaint();
	}

	public void removeAll() {
		shapeContainer.removeAll();
		repaint();
	}

	private class LocalWindowListener extends WindowAdapter {
		@Override
		public void windowClosing(WindowEvent e) {
			System.exit(0);
		}
	}

	public static void main(String[] args) {
		new DrawingFrame("Canvas");
	}
}
